@@ -6,7 +6,7 @@
 Functions for paths and files
 """
 #
-#  Copyright © 2018-2019 Dominic Davis-Foster <dominic@davis-foster.co.uk>
+#  Copyright © 2018-2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
 #  check_dependencies based on https://stackoverflow.com/a/29044693/3092681
 #  		Copyright © 2015 TehTechGuy
@@ -58,15 +58,27 @@ def copytree(src, dst, symlinks=False, ignore=None):
 	:type src: str
 	:param dst: Destination to copy file to
 	:type dst: str
-	:param symlinks: Whether to represent symbolic links in the source as symbolic links in the destination
-		If false or omitted, the contents and metadata of the linked files are copied to the new tree.
-		When symlinks is false, if the file pointed by the symlink doesn’t exist, an exception will be added in the list of errors raised in an Error exception at the end of the copy process. You can set the optional ignore_dangling_symlinks flag to true if you want to silence this exception. Notice that this option has no effect on platforms that don’t support os.symlink().
+	:param symlinks: Whether to represent symbolic links in the source as symbolic
+		links in the destination. If false or omitted, the contents and metadata
+		of the linked files are copied to the new tree. When symlinks is false,
+		if the file pointed by the symlink doesn't exist, an exception will be
+		added in the list of errors raised in an Error exception at the end of
+		the copy process. You can set the optional ignore_dangling_symlinks
+		flag to true if you want to silence this exception. Notice that this
+		option has no effect on platforms that don’t support :class:`python:os.symlink`.
 	:type symlinks: bool
-	:param ignore: A callable that will receive as its arguments the source directory, and a list of its contents.
-		The ignore callable will be called once for each directory that is copied.
-		The callable must return a sequence of directory and file names relative to the current directory (i.e. a subset of the items in its second argument); these names will then be ignored in the copy process. ignore_patterns() can be used to create such a callable that ignores names based on glob-style patterns.
+	:param ignore: A callable that will receive as its arguments the source
+		directory, and a list of its contents. The ignore callable will be
+		called once for each directory that is copied. The callable must return
+		a sequence of directory and file names relative to the current
+		directory (i.e. a subset of the items in its second argument); these
+		names will then be ignored in the copy process.
+		:class:`python:shutil.ignore_patterns` can be used to create such a callable
+		that ignores names based on
+		glob-style patterns.
 
 	:return:
+	:rtype:
 	"""
 	
 	import shutil
@@ -80,17 +92,31 @@ def copytree(src, dst, symlinks=False, ignore=None):
 			return shutil.copy2(s, d)
 
 
-def maybe_make(directory):
+def maybe_make(directory, mode=0o777, parents=False, exist_ok=False):
 	"""
-	Makes a directory only if it doesn't already exist
-
+	Create a directory at this given path, but only if the directory does
+	not already exist.
+	
 	:param directory: Directory to create
-	:type directory: str
-	
+	:type directory: str or pathlib.Path
+	:param mode: Combined with the process’ umask value to determine the file mode and access flags
+	:type mode:
+	:param parents: If ``False`` (the default), a missing parent raises a :class:`~python:FileNotFoundError`.
+		If ``True``, any missing parents of this path are created as needed; they are created with the
+		default permissions without taking mode into account (mimicking the POSIX mkdir -p command).
+	:type parents: bool
+	:param exist_ok: If ``False`` (the default), a :class:`~python:FileExistsError` is raised if the
+		target directory already exists. If ``True``, :class:`~python:FileExistsError` exceptions
+		will be ignored (same behavior as the POSIX mkdir -p command), but only if the last path
+		component is not an existing non-directory file.
+	:type exist_ok: bool
 	"""
 	
-	if not os.path.exists(directory):
-		os.makedirs(directory)
+	if not isinstance(directory, pathlib.Path):
+		directory = pathlib.Path(directory)
+	
+	if not directory.exists():
+		directory.mkdir(mode, parents, exist_ok)
 
 
 def parent_path(path):
@@ -98,21 +124,27 @@ def parent_path(path):
 	Returns the path of the parent directory for the given file or directory
 	
 	:param path: Path to find the parent for
-	:type path: str
+	:type path: str or pathlib.Path
 	
-	:return:
+	:return: The parent directory
+	:rtype: pathlib.Path
 	"""
 	
-	return os.path.abspath(os.path.join(path,os.pardir))
+	if not isinstance(path, pathlib.Path):
+		path = pathlib.Path(path)
+	
+	return path.parent
 
 
+# TODO: consolidate
 def relpath(path, relative_to=None):
 	"""
 	Returns the path for the given file or directory relative to the given directory
 	
 	:param path: Path to find the relative path for
 	:type path: str
-	:param relative_to: The directory to find the path relative to. Defaults to the current working directory (i.e. os.getcwd())
+	:param relative_to: The directory to find the path relative to.
+		Defaults to the current working directory (i.e. os.getcwd())
 	:type relative_to: str
 	
 	:return:
@@ -121,8 +153,10 @@ def relpath(path, relative_to=None):
 	if relative_to is None:
 		relative_to = os.getcwd()
 	
-	#if os.path.normpath(os.path.abspath(path)).startswith(os.path.normpath(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))):
-	if os.path.normpath(os.path.abspath(path)).startswith(os.path.normpath(os.path.dirname(os.path.dirname(os.path.abspath(relative_to))))):
+	# if os.path.normpath(os.path.abspath(path)).startswith(
+	# 		os.path.normpath(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))):
+	if os.path.normpath(os.path.abspath(path)).startswith(
+			os.path.normpath(os.path.dirname(os.path.dirname(os.path.abspath(relative_to))))):
 		return os.path.relpath(os.path.abspath(path))
 	else:
 		return os.path.abspath(path)
@@ -173,6 +207,8 @@ def delete(filename):
 	:return:
 	"""
 	
+	# TODO: docstring
+	
 	os.remove(os.path.join(os.getcwd(), filename))
 
 
@@ -188,6 +224,8 @@ def write(var, filename):
 	:return:
 	"""
 	
+	# TODO: docstring
+	
 	with open(os.path.join(os.getcwd(), filename), 'w') as f:
 		f.write(var)
 
@@ -203,6 +241,8 @@ def read(filename):
 	:return:
 	"""
 	
+	# TODO: docstring
+	
 	with open(os.path.join(os.getcwd(), filename)) as f:
 		return f.read()
 
@@ -219,5 +259,7 @@ def append(var, filename):
 	:return:
 	"""
 	
+	# TODO: docstring
+	
 	with open(os.path.join(os.getcwd(), filename), 'a') as f:
 		f.write(var)
