@@ -26,6 +26,8 @@ General Functions
 #
 
 import sys
+from collections.abc import Sequence
+from domdf_python_tools.doctools import is_documented_by
 
 pyversion = int(sys.version[0])  # Python Version
 
@@ -35,6 +37,7 @@ def as_text(value):
 	Convert the given value to a string
 	
 	:param value: value to convert to a string
+	:type value: any
 	
 	:rtype: str
 	"""
@@ -79,9 +82,10 @@ def chunks(l, n):
 	"""
 	Yield successive n-sized chunks from l.
 
-	:param l:
-	:param n:
-	:return:
+	:param l: The objects to yield chunks from
+	:type l: Sequence
+	:param n: The size of the chunks
+	:type n: int
 	"""
 	
 	for i in range(0, len(l), n):
@@ -93,9 +97,12 @@ def check_dependencies(dependencies, prt=True):
 	
 	:param dependencies:
 	:param prt:
+	
 	:return:
 	"""
+	
 	from pkgutil import iter_modules
+	
 	modules = set(x[1] for x in iter_modules())
 	
 	missing_modules = []
@@ -116,22 +123,6 @@ def check_dependencies(dependencies, prt=True):
 		return missing_modules
 
 
-def list2string(the_list, sep=","):
-	"""
-	Convert a list to a comma separated string
-
-	:param the_list: The list to convert to a string
-	:type the_list: list, tuple
-	:param sep: Separator to use for the string, default ","
-	:type sep: str
-
-	:return: Comma separated string
-	:rtype: str
-	"""
-	
-	return list2str(the_list, sep)
-
-
 def list2str(the_list, sep=","):
 	"""
 	Convert a list to a comma separated string
@@ -148,14 +139,20 @@ def list2str(the_list, sep=","):
 	return sep.join([str(x) for x in the_list])
 
 
+list2string = list2str
+
+
 def split_len(string, n):
 	"""
 	Split a string every x characters
 	
-	:param string:
+	:param string: The string to split
+	:type string: str
 	:param n:
+	:type n: int
 	
-	:return:
+	:return: The split string
+	:rtype: list
 	"""
 	
 	return [string[i:i + n] for i in range(0, len(string), n)]
@@ -172,7 +169,7 @@ def permutations(data, n=2):
 	:type data: list or string
 	:type n: int
 	
-	:rtype: list of tuples
+	:rtype: [tuple]
 	"""
 	
 	import itertools
@@ -188,108 +185,6 @@ def permutations(data, n=2):
 	return perms
 
 
-class bdict(dict):
-	"""
-	Returns a new dictionary initialized from an optional positional argument
-		and a possibly empty set of keyword arguments.
-	
-	Each key:value pair is entered into the dictionary in both directions,
-		so you can perform lookups with either the key or the value.
-	
-	If no positional argument is given, an empty dictionary is created.
-	If a positional argument is given and it is a mapping object, a dictionary
-		is created with the same key-value pairs as the mapping object.
-	Otherwise, the positional argument must be an iterable object.
-		Each item in the iterable must itself be an iterable with exactly two
-		objects. The first object of each item becomes a key in the new
-		dictionary, and the second object the corresponding value.
-	
-	If keyword arguments are given, the keyword arguments and their values are
-	added to the dictionary created from the positional argument.
-	
-	If an attempt is made to add a key or value that already exists in the
-		dictionary a ValueError will be raised
-	
-	Keys or values of "None", "True" and "False" will be stored internally as
-		"_None" "_True" and "_False" respectively
-	
-	Based on https://stackoverflow.com/a/1063393 by https://stackoverflow.com/users/9493/brian
-	"""
-	
-	def __init__(self, *args, **kwargs):
-		super().__init__(self)
-		if len(args) == 1:
-			for key, value in dict(*args).items():
-				self.__setitem__(key, value)
-		if len(args) == 0:
-			for key, value in kwargs.items():
-				self.__setitem__(key, value)
-	
-	def __setitem__(self, key, val):
-		if key in self or val in self:
-			if key in self and self[key] != val:
-				raise ValueError(f"The key '{key}' is already present in the dictionary")
-			if val in self and self[val] != key:
-				raise ValueError(f"The key '{val}' is already present in the dictionary")
-		
-		if key is None:
-			key = "_None"
-		if val is None:
-			val = "_None"
-		
-		if isinstance(key, bool):
-			if key:
-				key = "_True"
-			else:
-				key = "_False"
-		
-		if isinstance(val, bool):
-			if val:
-				val = "_True"
-			else:
-				val = "_False"
-		
-		dict.__setitem__(self, key, val)
-		dict.__setitem__(self, val, key)
-	
-	def __delitem__(self, key):
-		dict.__delitem__(self, self[key])
-		dict.__delitem__(self, key)
-	
-	def __getitem__(self, key):
-		if key is None:
-			key = "_None"
-		
-		if isinstance(key, bool):
-			if key:
-				key = "_True"
-			else:
-				key = "_False"
-		
-		val = dict.__getitem__(self, key)
-		
-		if val == "_None":
-			return None
-		elif val == "_True":
-			return True
-		elif val == "_False":
-			return False
-		else:
-			return val
-	
-	def __contains__(self, key):
-		if key is None:
-			key = "_None"
-		
-		if isinstance(key, bool):
-			if key:
-				key = "_True"
-			else:
-				key = "_False"
-		
-		return dict.__contains__(self, key)
-
-
 def cmp(x, y):
 	"""
 	Implementation of cmp for Python 3
@@ -301,3 +196,20 @@ def cmp(x, y):
 	"""
 	
 	return int((x > y) - (x < y))
+
+
+def printr(item, *args, **kwargs):
+	"""
+	Print the repr() of an object
+	"""
+	
+	return print(repr(item), *args, **kwargs)
+
+
+def printt(item, *args, **kwargs):
+	"""
+	Print the type of an object
+	"""
+	
+	return print(type(item), *args, **kwargs)
+
